#
# Copyright The NOMAD Authors.
#
# This file is part of NOMAD.
# See https://nomad-lab.eu for further info.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .aflow.parser import AFLOWParser
from .asr.parser import ASRParser
from .elastic.parser import ElasticParser
from .fhivibes.parser import FHIVibesParser
from .lobster.parser import LobsterParser
from .atomate.parser import AtomateParser
from .phonopy.parser import PhonopyParser
from .mofstructures.parser import MOFStructuresParser
from .quantum_espresso_phonon import QuantumEspressoPhononParser
from .quantum_espresso_epw import QuantumEspressoEPWParser
